You are viewing a plain text version of this content. The canonical link for it is here.
Posted to issues@ozone.apache.org by GitBox <gi...@apache.org> on 2020/06/05 10:14:47 UTC

[GitHub] [hadoop-ozone] runzhiwang opened a new pull request #1025: HDDS-3732. Improve the performance of SCM with 7.32% by avoid UUID.toString

runzhiwang opened a new pull request #1025:
URL: https://github.com/apache/hadoop-ozone/pull/1025


   
   
   ## What changes were proposed in this pull request?
   
   avoid UUID.toString
   
   ## What is the link to the Apache JIRA
   
   https://issues.apache.org/jira/browse/HDDS-3732
   
   ## How was this patch tested?
   
   Existed UT and IT.


----------------------------------------------------------------
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

For queries about this service, please contact Infrastructure at:
users@infra.apache.org



---------------------------------------------------------------------
To unsubscribe, e-mail: ozone-issues-unsubscribe@hadoop.apache.org
For additional commands, e-mail: ozone-issues-help@hadoop.apache.org


[GitHub] [hadoop-ozone] nandakumar131 merged pull request #1025: HDDS-3732. Avoid UUID#toString call in DatanodeDetails#getUuidString.

Posted by GitBox <gi...@apache.org>.
nandakumar131 merged pull request #1025:
URL: https://github.com/apache/hadoop-ozone/pull/1025


   


----------------------------------------------------------------
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

For queries about this service, please contact Infrastructure at:
users@infra.apache.org



---------------------------------------------------------------------
To unsubscribe, e-mail: ozone-issues-unsubscribe@hadoop.apache.org
For additional commands, e-mail: ozone-issues-help@hadoop.apache.org


[GitHub] [hadoop-ozone] nandakumar131 commented on pull request #1025: HDDS-3732. Avoid UUID#toString call in DatanodeDetails#getUuidString.

Posted by GitBox <gi...@apache.org>.
nandakumar131 commented on pull request #1025:
URL: https://github.com/apache/hadoop-ozone/pull/1025#issuecomment-639607373


   Thanks @runzhiwang for the improvement.


----------------------------------------------------------------
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

For queries about this service, please contact Infrastructure at:
users@infra.apache.org



---------------------------------------------------------------------
To unsubscribe, e-mail: ozone-issues-unsubscribe@hadoop.apache.org
For additional commands, e-mail: ozone-issues-help@hadoop.apache.org


[GitHub] [hadoop-ozone] nandakumar131 commented on pull request #1025: HDDS-3732. Improve the performance of SCM with 7.23% by avoid UUID.toString

Posted by GitBox <gi...@apache.org>.
nandakumar131 commented on pull request #1025:
URL: https://github.com/apache/hadoop-ozone/pull/1025#issuecomment-639500730


   Failure doesn't seem related, re-triggered the pre-commit checks.


----------------------------------------------------------------
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

For queries about this service, please contact Infrastructure at:
users@infra.apache.org



---------------------------------------------------------------------
To unsubscribe, e-mail: ozone-issues-unsubscribe@hadoop.apache.org
For additional commands, e-mail: ozone-issues-help@hadoop.apache.org


[GitHub] [hadoop-ozone] nandakumar131 commented on pull request #1025: HDDS-3732. Improve the performance of SCM with 7.23% by avoid UUID.toString

Posted by GitBox <gi...@apache.org>.
nandakumar131 commented on pull request #1025:
URL: https://github.com/apache/hadoop-ozone/pull/1025#issuecomment-639423664


   Thanks @runzhiwang for the improvement.
   We can also replace the `uuid.toString()` call inside `DatanodeDetails#toString()` to `strUuid`.


----------------------------------------------------------------
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

For queries about this service, please contact Infrastructure at:
users@infra.apache.org



---------------------------------------------------------------------
To unsubscribe, e-mail: ozone-issues-unsubscribe@hadoop.apache.org
For additional commands, e-mail: ozone-issues-help@hadoop.apache.org


[GitHub] [hadoop-ozone] runzhiwang commented on pull request #1025: HDDS-3732. Improve the performance of SCM with 7.23% by avoid UUID.toString

Posted by GitBox <gi...@apache.org>.
runzhiwang commented on pull request #1025:
URL: https://github.com/apache/hadoop-ozone/pull/1025#issuecomment-639464857


   @nandakumar131 Thanks for review. I have updated.


----------------------------------------------------------------
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

For queries about this service, please contact Infrastructure at:
users@infra.apache.org



---------------------------------------------------------------------
To unsubscribe, e-mail: ozone-issues-unsubscribe@hadoop.apache.org
For additional commands, e-mail: ozone-issues-help@hadoop.apache.org